.. NGP Iris documentation master file, created by
   sphinx-quickstart on Tue May 28 16:12:58 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to NGP Iris's documentation!
====================================
.. toctree::
   :maxdepth: 4
   :caption: Contents:
   
   README <README.md>
   Technical documentation <modules.rst>
   Tutorial <Tutorial.md>
   Changelog for IRIS 5 <IRIS_5_changelog.md>

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
